Package: blockmodeling
Type: Package
Title: Generalized and Classical Blockmodeling of Valued Networks
Version: 1.1.8
Date: 2025-07-25
Imports: stats, methods, Matrix, parallel
Suggests: sna, doRNG, doParallel, foreach
Depends: R (>= 2.10)
Authors@R: c(person(given = "Aleš", family = "Žiberna", email = "ales.ziberna@gmail.com", role = c("aut", "cre")), person( family ="Cugmas", given = "Marjan", email = "marjan.cugmas@fdv.uni-lj.si", role = c("ctb")))
Maintainer: Aleš Žiberna <ales.ziberna@gmail.com>
Description: This is primarily meant as an implementation of generalized blockmodeling for valued networks.
 In addition, measures of similarity or dissimilarity based on structural equivalence and 
 regular equivalence (REGE algorithms) can be computed and partitioned matrices can be plotted:
 Žiberna (2007)<doi:10.1016/j.socnet.2006.04.002>, Žiberna (2008)<doi:10.1080/00222500701790207>,
 Žiberna (2014)<doi:10.1016/j.socnet.2014.04.002>.
License: GPL (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-07-25 09:44:14 UTC; zibernaa
Author: Aleš Žiberna [aut, cre],
  Marjan Cugmas [ctb]
Repository: CRAN
Date/Publication: 2025-07-25 10:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 07:34:54 UTC; unix
Archs: blockmodeling.so.dSYM
