# Generated by roxygen2: do not edit by hand

S3method(funByBlocks,default)
S3method(funByBlocks,opt.more.par)
S3method(funByBlocks,optMorePar)
S3method(plot,check.these.par)
S3method(plot,crit.fun)
S3method(plot,critFun)
S3method(plot,mat)
S3method(plot,opt.more.par)
S3method(plot,opt.more.par.mode)
S3method(plot,opt.par)
S3method(plot,opt.par.mode)
S3method(plot,optMorePar)
S3method(plot,optMoreParMode)
S3method(plot,optPar)
S3method(plot,optParMode)
S3method(print,optMorePar)
export(EM)
export(IM)
export(REGD.for)
export(REGD.ne.for)
export(REGD.ow.for)
export(REGE)
export(REGE.FC)
export(REGE.FC.ow)
export(REGE.for)
export(REGE.ne.for)
export(REGE.nm.diag.for)
export(REGE.nm.for)
export(REGE.nm.ne.for)
export(REGE.ow)
export(REGE.ow.for)
export(REGE.ow.ne.for)
export(REGE.ownm.diag.for)
export(REGE.ownm.for)
export(REGE.ownm.ne.for)
export(RF)
export(ad)
export(canClu)
export(canCluUniqe)
export(clu)
export(crand)
export(crand2)
export(critFunC)
export(encodeToZeroIndexed)
export(err)
export(expandMat)
export(find.cut)
export(find.m)
export(find.m2)
export(formatA)
export(fun.by.blocks)
export(funByBlocks)
export(genMatrixMult)
export(genRandomPar)
export(gplot1)
export(gplot2)
export(ircNorm)
export(loadmatrix)
export(loadnetwork)
export(loadnetwork2)
export(loadnetwork3)
export(loadnetwork4)
export(loadpajek)
export(loadvector)
export(loadvector2)
export(nanRep)
export(nkpar)
export(nkpartitions)
export(numClust)
export(one2two)
export(optParC)
export(optRandomParC)
export(orderClu)
export(partitions)
export(plot.mat)
export(plotArray)
export(plotMat)
export(plotMatNm)
export(printBlocks)
export(rand)
export(rand2)
export(recode)
export(relInv)
export(relInv2)
export(reorderImage)
export(savematrix)
export(savenetwork)
export(savevector)
export(sedist)
export(splitClu)
export(splitCluRes)
export(ss)
export(ssNa)
export(two2one)
export(unlistClu)
export(unlistCluInt)
import(Matrix)
import(methods)
import(parallel)
importFrom(grDevices,gray)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.default)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,optimize)
importFrom(stats,runif)
importFrom(utils,citation)
importFrom(utils,read.table)
importFrom(utils,write.table)
useDynLib(blockmodeling, .registration = TRUE)
